window.Gleam.initSearch([{"doc":"jackson","title":"jackson","content":"# jackson\n\n[![Package Version](https://img.shields.io/hexpm/v/jackson)](https://hex.pm/packages/jackson)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/jackson/)\n\n```sh\ngleam add jackson\n```\n\n## Decoding a json value\n\n```gleam\nimport jackson\nimport gleam/result\nimport gleam/dynamic\n\npub fn main() {\n  fetch_value()\n  |&gt; jackson.parse\n  |&gt; result.map(\n    jackson.decode(dynamic.decode2(Constructor, field(&quot;id&quot;, dynamic.int), field(&quot;name&quot;, dynamic.string))\n  )\n}\n```\n\n## Encoding a json value\n\n```gleam\nimport jackson\n\njackson.object(\n  #(&quot;id&quot;, jackson.int(2)),\n  #(&quot;name&quot;, jackson.string(&quot;michael&quot;))\n)\n|&gt; jackson.to_string()\n// {&quot;id&quot;: 2, &quot;name&quot;: &quot;michael&quot;}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/jackson&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"jackson","title":"array","content":"pub fn array(entries: List(Json)) -&gt; Json\n build an array from a list of json values\nSynonyms:\njackson.array\njackson array","url":"jackson.html#array"},{"doc":"jackson","title":"bool","content":"pub fn bool(value: Bool) -&gt; Json\n build a json boolean value\nSynonyms:\njackson.bool\njackson bool","url":"jackson.html#bool"},{"doc":"jackson","title":"decode","content":"pub fn decode(\n  json: Json,\n  decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; Result(a, List(DecodeError))\n take a parsed json value from `jackson.parse` and decode it from a dynamic\nSynonyms:\njackson.decode\njackson decode","url":"jackson.html#decode"},{"doc":"jackson","title":"dynamic_to_json","content":"pub fn dynamic_to_json(\n  dyn: Dynamic,\n) -&gt; Result(Json, List(DecodeError))\n take a dynamic value, created either manually or from the `jackson.decode` function,\n and turn it back into json. This is how the following values are converted:\n\n   - Int -&gt; json.Int(inner)\n   - Float -&gt; json.Float(inner)\n   - String -&gt; json.String(inner)\n   - Bool -&gt; json.Bool(inner)\n   - Nil -&gt; json.Null\n   - List(#(String, Json)) -&gt; json.Object(entries)\n   - List(Json) -&gt; json.Array(entries)\n\n A slight problem is that gleam&#39;s `dynamic.tuple2` is unable to differentiate between\n a tuple and an array of length two. Additionally, if your json contains an array, whose\n children are all arrays of length two where the value at index 0 is a string,\n (such as `[[&quot;a&quot;, 1], [&quot;b&quot;, 2], [&quot;c&quot;, 3], [&quot;d&quot;, 4]]`) then this function will re-encode it\n as though it were the following object:\n\n json\n {\n   &quot;a&quot;: 1,\n   &quot;b&quot;: 2,\n   &quot;c&quot;: 3,\n   &quot;d&quot;: 4\n }\n \nSynonyms:\njackson.dynamic_to_json\njackson dynamic_to_json","url":"jackson.html#dynamic_to_json"},{"doc":"jackson","title":"float","content":"pub fn float(value: Float) -&gt; Json\n build a json float value\nSynonyms:\njackson.float\njackson float","url":"jackson.html#float"},{"doc":"jackson","title":"int","content":"pub fn int(value: Int) -&gt; Json\n build a json number value\nSynonyms:\njackson.int\njackson int","url":"jackson.html#int"},{"doc":"jackson","title":"null","content":"pub fn null() -&gt; Json\n build a json null value\nSynonyms:\njackson.null\njackson null","url":"jackson.html#null"},{"doc":"jackson","title":"object","content":"pub fn object(entries: List(#(String, Json))) -&gt; Json\n build a json object from a list of keys and values, similar to `dict.from_list`\nSynonyms:\njackson.object\njackson object","url":"jackson.html#object"},{"doc":"jackson","title":"parse","content":"pub fn parse(in: String) -&gt; Result(Json, String)\n parse a string into json\nSynonyms:\njackson.parse\njackson parse","url":"jackson.html#parse"},{"doc":"jackson","title":"resolve_pointer","content":"pub fn resolve_pointer(\n  json: Json,\n  pointer: String,\n) -&gt; Result(Json, Nil)\n resolve a json pointer, starting with a &quot;/&quot; or a &quot;#/&quot;\n *note* json pointers starting with a &quot;#/&quot; will be resolved with reference to the\n current json value, and not a remote resource\nSynonyms:\njackson.resolve_pointer\njackson resolve_pointer","url":"jackson.html#resolve_pointer"},{"doc":"jackson","title":"string","content":"pub fn string(value: String) -&gt; Json\n build a json string value\nSynonyms:\njackson.string\njackson string","url":"jackson.html#string"},{"doc":"jackson","title":"to_string","content":"pub fn to_string(json: Json) -&gt; String\n encode json to string (uses `jackson.to_string_builder` under the hood)\nSynonyms:\njackson.to_string\njackson to_string","url":"jackson.html#to_string"},{"doc":"jackson","title":"to_string_builder","content":"pub fn to_string_builder(json: Json) -&gt; StringBuilder\n encode json to a string builder\nSynonyms:\njackson.to_string_builder\njackson to_string_builder","url":"jackson.html#to_string_builder"},{"doc":"jackson","title":"jackson","content":"","url":"jackson.html"}]);